/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 02884
 |        NATIONAL TREATMENT IMPROVEMENT EVALUATION STUDY (NTIES),
 |                               1992-1997
 |          (DATASET 0004: NTIES PATIENT RECORD ABSTRACTION FORM
 |                                (NPRAF))
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 02884-0004-statasetup.do)
 |
 **************************************************************************/

set mem 9m  /* Allocating 9 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "National Treatment Improvement Evaluation Study (NTIES), 1992-1997, NTIES Patient Record Abstraction Form (NPRAF)"

#delimit ;
label define PRGMTYPE  1 "CRITICAL POPULATIONS" 2 "CORRECTIONAL SETTINGS"
                       3 "OFFENDERS" 4 "TARGET CITIES" 5 "JUSTICE"
                       6 "PUBLIC HOUSING" ;
label define TRT2      1 "SHORT-TERM RESIDENTIAL/IN-PATIENT"
                       2 "LONG-TERM RESIDENTIAL/IN-PATIENT"
                       3 "OUT-PATIENT METHADONE" 4 "AMBULATORY OUT-PATIENT" ;
label define PRG2      1 "AJJ/PH" 2 "CRIMINAL JUSTICE" 3 "TARGET CITIES" ;
label define CELL      1 "CP/SR" 2 "CP/LR" 3 "CP/OP" 4 "TC/SR" 5 "TC/LR"
                       6 "TC/OP" 7 "CJ/SR" 8 "CJ/LR" 9 "CJ/OP" 10 "METHADONE" ;
label define CELL2     1 "METHADONE" 2 "NON-METHADONE OUT-PATIENT"
                       3 "SHORT-TERM RESIDENTIAL" 4 "LONG-TERM RESIDENTIAL"
                       5 "CORRECTIONAL SETTINGS" ;
label define F3_1      -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" ;
label define F3_2      -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F3_3      -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" ;
label define F4        -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE"
                       1 "PRIV HLTH INSURANCE/PRIV HLTH PLAN/HMO"
                       2 "SELF-PAY/RS MONEY" 3 "MEDICAID/CHAMPUS/CHAMPVA"
                       4 "OTHER INSURANCE (SPECIFY)"
                       5 "OTHER GOVERNMENT SOURCE"
                       6 "ANOTHER SOURCE (SPECIFY)" ;
label define F7        -3 "MISSING" -2 "NOT AVAILABLE" -1 "REFUSED" 0 "NONE"
                       1 "LESS THAN 500" 2 "500-1000" 3 "1001-5000"
                       4 "MORE THAN 5000" ;
label define F7A_1     -9 "LEGITIMATE SKIP" -3 "MISSING" -2 "NOT AVAILABLE"
                       0 "NONE" 1 "50 OR LESS" 2 "51-500" 3 "MORE THAN 500"
                       4 "TOTAL CODED IN F7" ;
label define F7A_2     -9 "LEGITIMATE SKIP" -3 "MISSING" -2 "NOT AVAILABLE"
                       0 "NONE" 1 "50 OR LESS" 2 "51-500" 3 "MORE THAN 500"
                       4 "TOTAL CODED IN F7" ;
label define F7A_3     -9 "LEGITIMATE SKIP" -3 "MISSING" -2 "NOT AVAILABLE"
                       0 "NONE" 1 "LESS THAN 500" 2 "500-2000"
                       3 "MORE THAN 2000" 4 "TOTAL CODED IN F7" ;
label define F8        -3 "MISSING" -2 "NOT AVAILABLE" 1 "YES" 2 "NO" ;
label define F9        -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F10A      -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "OPIATE DEPENDENCE (304.00-09/.70-79)"
                       2 "ALCOHOL ABUSE (305.00-09)"
                       3 "ALCOHOL DEPENDENCE (303.90-99)"
                       4 "COCAINE ABUSE (305.60-69)"
                       5 "COCAINE DEPENDENCE (304.20-29)"
                       6 "MARIJUANA ABUSE (305.20-29)"
                       7 "MARIJUANA DEPENDENCE (304.30-39)"
                       8 "OTHER DRUG ABUSE (OTHER 305.XX)"
                       9 "OTHER DRUG DEPENDENCE(OTHER 304.XX)"
                       10 "PSYCHIATRIC/NON-DRUG (294-302.99,306-320"
                       11 "ORGANIC (1-293.99, 320-999)"
                       12 "UNRECOGNIZED CODE (>999)" ;
label define F10B      -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "OPIATE DEPENDENCE (304.00-09/.70-79)"
                       2 "ALCOHOL ABUSE (305.00-09)"
                       3 "ALCOHOL DEPENDENCE (303.90-99)"
                       4 "COCAINE ABUSE (305.60-69)"
                       5 "COCAINE DEPENDENCE (304.20-29)"
                       6 "MARIJUANA ABUSE (305.20-29)"
                       7 "MARIJUANA DEPENDENCE (304.30-39)"
                       8 "OTHER DRUG ABUSE (OTHER 305.XX)"
                       9 "OTHER DRUG DEPENDENCE(OTHER 304.XX)"
                       10 "PSYCHIATRIC/NON-DRUG (294-302.99,306-320"
                       11 "ORGANIC (1-293.99, 320-999)"
                       12 "UNRECOGNIZED CODE (>999)" ;
label define F11       -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F11B      -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "OPIATE DEPENDENCE (304.00-09/.70-79)"
                       2 "ALCOHOL ABUSE (305.00-09)"
                       3 "ALCOHOL DEPENDENCE (303.90-99)"
                       4 "COCAINE ABUSE (305.60-69)"
                       5 "COCAINE DEPENDENCE (304.20-29)"
                       6 "MARIJUANA ABUSE (305.20-29)"
                       7 "MARIJUANA DEPENDENCE (304.30-39)"
                       8 "OTHER DRUG ABUSE (OTHER 305.XX)"
                       9 "OTHER DRUG DEPENDENCE(OTHER 304.XX)"
                       10 "PSYCHIATRIC/NON-DRUG (294-302.99,306-320"
                       11 "ORGANIC (1-293.99, 320-999)"
                       12 "UNRECOGNIZED CODE (>999)" ;
label define F11C      -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "OPIATE DEPENDENCE (304.00-09/.70-79)"
                       2 "ALCOHOL ABUSE (305.00-09)"
                       3 "ALCOHOL DEPENDENCE (303.90-99)"
                       4 "COCAINE ABUSE (305.60-69)"
                       5 "COCAINE DEPENDENCE (304.20-29)"
                       6 "MARIJUANA ABUSE (305.20-29)"
                       7 "MARIJUANA DEPENDENCE (304.30-39)"
                       8 "OTHER DRUG ABUSE (OTHER 305.XX)"
                       9 "OTHER DRUG DEPENDENCE(OTHER 304.XX)"
                       10 "PSYCHIATRIC/NON-DRUG (294-302.99,306-320"
                       11 "ORGANIC (1-293.99, 320-999)"
                       12 "UNRECOGNIZED CODE (>999)" ;
label define F12       -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F12C      -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F13M1     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F13M2     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F13M3     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F13M4     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F13M5     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F13M6     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F13M7     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F13M8     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F13M9     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F13M10    -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F13M11    -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F13M12    -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F13M13    -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F14       -7 "NO DATA" 1 "YES" ;
label define F14A1     -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F14A1M1   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A1M2   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A1M3   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A1M4   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A1M5   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A1M6   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A1M7   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A1M8   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A1M9   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A2     -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F14A2M1   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A2M2   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A2M3   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A2M4   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A2M6   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A2M8   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A2M9   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A3     -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F14A3M1   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A3M2   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A3M3   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A3M4   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A3M6   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A3M8   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A3M9   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A4     -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F14A4M1   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A4M2   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A4M3   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A4M4   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A4M5   -7 "NO DATA" 2 "NO" ;
label define F14A4M6   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A4M7   -7 "NO DATA" 2 "NO" ;
label define F14A4M8   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A4M9   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A5     -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F14A5M1   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A5M2   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A5M3   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A5M4   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A5M6   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A5M8   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A5M9   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A6     -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F14A6M1   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A6M2   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A6M3   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A6M4   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A6M6   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A6M8   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A6M9   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A7     -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F14A7M1   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A7M2   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A7M3   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A7M4   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A7M5   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A7M6   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A7M8   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A7M9   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A8     -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F14A8M1   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A8M2   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A8M3   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A8M4   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A8M6   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A8M7   -7 "NO DATA" 2 "NO" ;
label define F14A8M8   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A8M9   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A9     -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F14A9M1   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A9M2   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A9M3   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A9M4   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A9M6   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A9M7   -7 "NO DATA" 2 "NO" ;
label define F14A9M8   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A9M9   -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A10    -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F14A10M1  -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A10M2  -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A10M3  -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A10M7  -7 "NO DATA" 2 "NO" ;
label define F14A10M8  -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A10M9  -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A11    -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F14A11M1  -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A11M2  -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A11M3  -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A11M7  -7 "NO DATA" 2 "NO" ;
label define F14A11M8  -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A11M9  -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A12    -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F14A12M1  -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A12M2  -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A12M3  -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A12M5  -7 "NO DATA" 2 "NO" ;
label define F14A12M7  -7 "NO DATA" 2 "NO" ;
label define F14A12M8  -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F14A12M9  -7 "NO DATA" 1 "YES" 2 "NO" ;
label define F15A1     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "ONE TIME" 2 "2-3 TIMES" 3 "4-10 TIMES"
                       4 "11 OR MORE TIMES" 7 "NUMBER UNCERTAIN" ;
label define F15A2     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "ONE TIME" 2 "2-3 TIMES" 3 "4-10 TIMES"
                       4 "11 OR MORE TIMES" 7 "NUMBER UNCERTAIN" ;
label define F15A3     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "ONE TIME" 2 "2-3 TIMES" 3 "4-10 TIMES"
                       4 "11 OR MORE TIMES" 7 "NUMBER UNCERTAIN" ;
label define F15A4     -3 "MISSING" -2 "NOT AVAILABLE" 1 "ONE TIME"
                       2 "2-3 TIMES" 3 "4-10 TIMES" 4 "11 OR MORE TIMES"
                       7 "NUMBER UNCERTAIN" ;
label define F15A6     -3 "MISSING" -2 "NOT AVAILABLE" 1 "ONE TIME"
                       2 "2-3 TIMES" 3 "4-10 TIMES" 4 "11 OR MORE TIMES"
                       7 "NUMBER UNCERTAIN" ;
label define F15A7     -3 "MISSING" -2 "NOT AVAILABLE" 1 "ONE TIME"
                       2 "2-3 TIMES" 3 "4-10 TIMES" 4 "11 OR MORE TIMES"
                       7 "NUMBER UNCERTAIN" ;
label define F15A8     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "ONE TIME" 2 "2-3 TIMES" 3 "4-10 TIMES"
                       4 "11 OR MORE TIMES" 7 "NUMBER UNCERTAIN" ;
label define F15A9     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "ONE TIME" 2 "2-3 TIMES" 3 "4-10 TIMES"
                       4 "11 OR MORE TIMES" 7 "NUMBER UNCERTAIN" ;
label define F15A10    -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "ONE TIME" 2 "2-3 TIMES" 3 "4-10 TIMES"
                       4 "11 OR MORE TIMES" 7 "NUMBER UNCERTAIN" ;
label define F15A11    -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "ONE TIME" 2 "2-3 TIMES" 3 "4-10 TIMES"
                       4 "11 OR MORE TIMES" 7 "NUMBER UNCERTAIN" ;
label define F15A12    -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "ONE TIME" 2 "2-3 TIMES" 3 "4-10 TIMES"
                       4 "11 OR MORE TIMES" 7 "NUMBER UNCERTAIN" ;
label define F15A13    -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       -1 "REFUSED" 1 "ONE TIME" 2 "2-3 TIMES" 3 "4-10 TIMES"
                       4 "11 OR MORE TIMES" 7 "NUMBER UNCERTAIN" ;
label define F15A14    -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       -1 "REFUSED" 1 "ONE TIME" 2 "2-3 TIMES" 3 "4-10 TIMES"
                       4 "11 OR MORE TIMES" 7 "NUMBER UNCERTAIN" ;
label define F15A15    -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       -1 "REFUSED" 1 "ONE TIME" 2 "2-3 TIMES" 3 "4-10 TIMES"
                       4 "11 OR MORE TIMES" 7 "NUMBER UNCERTAIN" ;
label define F15A16    -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       -1 "REFUSED" 1 "ONE TIME" 2 "2-3 TIMES" 3 "4-10 TIMES"
                       4 "11 OR MORE TIMES" 7 "NUMBER UNCERTAIN" ;
label define F15A17    -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       -1 "REFUSED" 1 "ONE TIME" 2 "2-3 TIMES" 3 "4-10 TIMES"
                       4 "11 OR MORE TIMES" 7 "NUMBER UNCERTAIN" ;
label define F15A18    -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "ONE TIME" 2 "2-3 TIMES" 7 "NUMBER UNCERTAIN" ;
label define F15A19    -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "ONE TIME" 2 "2-3 TIMES" 3 "4-10 TIMES"
                       4 "11 OR MORE TIMES" 7 "NUMBER UNCERTAIN" ;
label define F15A20    -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       7 "SERVICE RECEIVED" ;
label define F15A21    -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       7 "SERVICE RECEIVED" ;
label define F15A22    -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "ONE TIME" 3 "4-10 TIMES" 7 "NUMBER UNCERTAIN" ;
label define F15A23    -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "ONE TIME" 2 "2-3 TIMES" 3 "4-10 TIMES"
                       4 "11 OR MORE TIMES" 7 "NUMBER UNCERTAIN" ;
label define F15A24    -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" 1 "ONE TIME" 2 "2-3 TIMES"
                       3 "4-10 TIMES" 4 "11 OR MORE TIMES"
                       7 "NUMBER UNCERTAIN" ;
label define F16M1     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" 3 "NO RX IN RECORD" ;
label define F16M2     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" 3 "NO RX IN RECORD" ;
label define F16M3     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" 3 "NO RX IN RECORD" ;
label define F16M4     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" 3 "NO RX IN RECORD" ;
label define F16M5     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" 3 "NO RX IN RECORD" ;
label define F16M6     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" 3 "NO RX IN RECORD" ;
label define F16M7     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" 3 "NO RX IN RECORD" ;
label define F16M8     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" 3 "NO RX IN RECORD" ;
label define F16M9     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" 3 "NO RX IN RECORD" ;
label define F16M11    -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" 3 "NO RX IN RECORD" ;
label define F16M12    -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" 3 "NO RX IN RECORD" ;
label define F17       -3 "MISSING" -2 "NOT AVAILABLE" 1 "YES" 2 "NO" ;
label define F17A1     -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F17A1A4   -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "30 OR LESS" 2 "31-40" 3 "41-50" 4 "MORE THAN 50" ;
label define F17A1A5   -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F17A2     -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F17A2A4   -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "30 OR LESS" 2 "31-40" 3 "41-50" 4 "MORE THAN 50" ;
label define F17A2A5   -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F17A3     -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F17A3A4   -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "30 OR LESS" 2 "31-40" 3 "41-50" 4 "MORE THAN 50" ;
label define F17A3A5   -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F17A4     -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F17A4A4   -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "30 OR LESS" 2 "31-40" 3 "41-50" 4 "MORE THAN 50" ;
label define F17A4A5   -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F17A5     -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F17A5A4   -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "30 OR LESS" 2 "31-40" 3 "41-50" 4 "MORE THAN 50" ;
label define F17A5A5   -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F17A6     -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F17A6A4   -5 "NOT APPLICABLE" -3 "MISSING" 1 "30 OR LESS"
                       2 "31-40" 3 "41-50" 4 "MORE THAN 50" ;
label define F17A6A5   -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F17A7     -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F17A7A4   -5 "NOT APPLICABLE" -3 "MISSING" 1 "30 OR LESS"
                       2 "31-40" 3 "41-50" 4 "MORE THAN 50" ;
label define F17A7A5   -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define F17A8     -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F17A8A4   -5 "NOT APPLICABLE" -3 "MISSING" 1 "30 OR LESS"
                       2 "31-40" 3 "41-50" 4 "MORE THAN 50" ;
label define F17A8A5   -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define F17A9     -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F17A9A4   -5 "NOT APPLICABLE" -3 "MISSING" 1 "30 OR LESS"
                       2 "31-40" 3 "41-50" 4 "MORE THAN 50" ;
label define F17A9A5   -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F17A10    -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F17A10A4  -5 "NOT APPLICABLE" -3 "MISSING" 1 "30 OR LESS"
                       2 "31-40" 3 "41-50" 4 "MORE THAN 50" ;
label define F17A10A5  -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F17A11    -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F17A11A4  -5 "NOT APPLICABLE" -3 "MISSING" 1 "30 OR LESS"
                       2 "31-40" 3 "41-50" 4 "MORE THAN 50" ;
label define F17A11A5  -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F17A12    -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F17A12A4  -5 "NOT APPLICABLE" -3 "MISSING" 1 "30 OR LESS"
                       2 "31-40" 3 "41-50" 4 "MORE THAN 50" ;
label define F17A12A5  -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F17A13    -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F17A13A4  -5 "NOT APPLICABLE" -3 "MISSING" 1 "30 OR LESS"
                       2 "31-40" 3 "41-50" 4 "MORE THAN 50" ;
label define F17A13A5  -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F17A14    -10 "PRIOR TO TREATMENT" -8 "PREADMISSION"
                       -7 "NO DATA" -5 "NOT APPLICABLE"
                       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" -1 "REFUSED" ;
label define F17A14A4  -5 "NOT APPLICABLE" -3 "MISSING" 1 "30 OR LESS"
                       2 "31-40" 3 "41-50" 4 "MORE THAN 50" ;
label define F17A14A5  -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F17B      -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F18       -4 "MULTIPLE RESPONSES" -3 "MISSING"
                       -2 "NOT AVAILABLE" 1 "YES" 2 "NO" ;
label define F19       -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO" ;
label define F20       -3 "MISSING" -2 "NOT AVAILABLE" 1 "YES" 2 "NO" ;
label define F20A1     -5 "NOT APPLICABLE" -3 "MISSING" 1 "YES"
                       2 "NO OR UNSPECIFIED" ;
label define F20A2     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO OR UNSPECIFIED" ;
label define F20A3     -5 "NOT APPLICABLE" -3 "MISSING" -2 "NOT AVAILABLE"
                       1 "YES" 2 "NO OR UNSPECIFIED" ;
label define F20B      -5 "NOT APPLICABLE" -3 "MISSING" 1 "IN A LINKED SDU"
                       2 "IN AN UNCONNECTED SDU"
                       3 "IN BOTH KINDS (MULTIPLE SDUs)"
                       4 "UNKNOWN/NOT IN RECORD" ;
label define PRAFMODE  1 "FULL NPRAF" 2 "MINI NPRAF" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace PRGMTYPE = . if (PRGMTYPE <= -1 )
replace TRT2 = . if (TRT2 <= -1 )
replace PRG2 = . if (PRG2 <= -1 )
replace CELL = . if (CELL <= -1 )
replace CELL2 = . if (CELL2 <= -1 )
replace F3_1 = . if (F3_1 <= -1 )
replace F3_2 = . if (F3_2 <= -1 )
replace F3_3 = . if (F3_3 <= -1 )
replace F4 = . if (F4 <= -1 )
replace F7 = . if (F7 <= -1 )
replace F7A_1 = . if (F7A_1 <= -1 )
replace F7A_2 = . if (F7A_2 <= -1 )
replace F7A_3 = . if (F7A_3 <= -1 )
replace F8 = . if (F8 <= -1 )
replace F9 = . if (F9 <= -1 )
replace F10A = . if (F10A <= -1 )
replace F10B = . if (F10B <= -1 )
replace F11 = . if (F11 <= -1 )
replace F11B = . if (F11B <= -1 )
replace F11C = . if (F11C <= -1 )
replace F12 = . if (F12 <= -1 )
replace F12C = . if (F12C <= -1 )
replace F13M1 = . if (F13M1 <= -1 )
replace F13M2 = . if (F13M2 <= -1 )
replace F13M3 = . if (F13M3 <= -1 )
replace F13M4 = . if (F13M4 <= -1 )
replace F13M5 = . if (F13M5 <= -1 )
replace F13M6 = . if (F13M6 <= -1 )
replace F13M7 = . if (F13M7 <= -1 )
replace F13M8 = . if (F13M8 <= -1 )
replace F13M9 = . if (F13M9 <= -1 )
replace F13M10 = . if (F13M10 <= -1 )
replace F13M11 = . if (F13M11 <= -1 )
replace F13M12 = . if (F13M12 <= -1 )
replace F13M13 = . if (F13M13 <= -1 )
replace F14 = . if (F14 <= -1 )
replace F14A1 = . if (F14A1 <= -1.00 )
replace F14A1M1 = . if (F14A1M1 <= -1 )
replace F14A1M2 = . if (F14A1M2 <= -1 )
replace F14A1M3 = . if (F14A1M3 <= -1 )
replace F14A1M4 = . if (F14A1M4 <= -1 )
replace F14A1M5 = . if (F14A1M5 <= -1 )
replace F14A1M6 = . if (F14A1M6 <= -1 )
replace F14A1M7 = . if (F14A1M7 <= -1 )
replace F14A1M8 = . if (F14A1M8 <= -1 )
replace F14A1M9 = . if (F14A1M9 <= -1 )
replace F14A2 = . if (F14A2 <= -1.00 )
replace F14A2M1 = . if (F14A2M1 <= -1 )
replace F14A2M2 = . if (F14A2M2 <= -1 )
replace F14A2M3 = . if (F14A2M3 <= -1 )
replace F14A2M4 = . if (F14A2M4 <= -1 )
replace F14A2M6 = . if (F14A2M6 <= -1 )
replace F14A2M8 = . if (F14A2M8 <= -1 )
replace F14A2M9 = . if (F14A2M9 <= -1 )
replace F14A3 = . if (F14A3 <= -1.00 )
replace F14A3M1 = . if (F14A3M1 <= -1 )
replace F14A3M2 = . if (F14A3M2 <= -1 )
replace F14A3M3 = . if (F14A3M3 <= -1 )
replace F14A3M4 = . if (F14A3M4 <= -1 )
replace F14A3M6 = . if (F14A3M6 <= -1 )
replace F14A3M8 = . if (F14A3M8 <= -1 )
replace F14A3M9 = . if (F14A3M9 <= -1 )
replace F14A4 = . if (F14A4 <= -1.00 )
replace F14A4M1 = . if (F14A4M1 <= -1 )
replace F14A4M2 = . if (F14A4M2 <= -1 )
replace F14A4M3 = . if (F14A4M3 <= -1 )
replace F14A4M4 = . if (F14A4M4 <= -1 )
replace F14A4M5 = . if (F14A4M5 <= -1 )
replace F14A4M6 = . if (F14A4M6 <= -1 )
replace F14A4M7 = . if (F14A4M7 <= -1 )
replace F14A4M8 = . if (F14A4M8 <= -1 )
replace F14A4M9 = . if (F14A4M9 <= -1 )
replace F14A5 = . if (F14A5 <= -1.00 )
replace F14A5M1 = . if (F14A5M1 <= -1 )
replace F14A5M2 = . if (F14A5M2 <= -1 )
replace F14A5M3 = . if (F14A5M3 <= -1 )
replace F14A5M4 = . if (F14A5M4 <= -1 )
replace F14A5M6 = . if (F14A5M6 <= -1 )
replace F14A5M8 = . if (F14A5M8 <= -1 )
replace F14A5M9 = . if (F14A5M9 <= -1 )
replace F14A6 = . if (F14A6 <= -1.00 )
replace F14A6M1 = . if (F14A6M1 <= -1 )
replace F14A6M2 = . if (F14A6M2 <= -1 )
replace F14A6M3 = . if (F14A6M3 <= -1 )
replace F14A6M4 = . if (F14A6M4 <= -1 )
replace F14A6M6 = . if (F14A6M6 <= -1 )
replace F14A6M8 = . if (F14A6M8 <= -1 )
replace F14A6M9 = . if (F14A6M9 <= -1 )
replace F14A7 = . if (F14A7 <= -1.00 )
replace F14A7M1 = . if (F14A7M1 <= -1 )
replace F14A7M2 = . if (F14A7M2 <= -1 )
replace F14A7M3 = . if (F14A7M3 <= -1 )
replace F14A7M4 = . if (F14A7M4 <= -1 )
replace F14A7M5 = . if (F14A7M5 <= -1 )
replace F14A7M6 = . if (F14A7M6 <= -1 )
replace F14A7M8 = . if (F14A7M8 <= -1 )
replace F14A7M9 = . if (F14A7M9 <= -1 )
replace F14A8 = . if (F14A8 <= -1.00 )
replace F14A8M1 = . if (F14A8M1 <= -1 )
replace F14A8M2 = . if (F14A8M2 <= -1 )
replace F14A8M3 = . if (F14A8M3 <= -1 )
replace F14A8M4 = . if (F14A8M4 <= -1 )
replace F14A8M6 = . if (F14A8M6 <= -1 )
replace F14A8M7 = . if (F14A8M7 <= -1 )
replace F14A8M8 = . if (F14A8M8 <= -1 )
replace F14A8M9 = . if (F14A8M9 <= -1 )
replace F14A9 = . if (F14A9 <= -1.00 )
replace F14A9M1 = . if (F14A9M1 <= -1 )
replace F14A9M2 = . if (F14A9M2 <= -1 )
replace F14A9M3 = . if (F14A9M3 <= -1 )
replace F14A9M4 = . if (F14A9M4 <= -1 )
replace F14A9M6 = . if (F14A9M6 <= -1 )
replace F14A9M7 = . if (F14A9M7 <= -1 )
replace F14A9M8 = . if (F14A9M8 <= -1 )
replace F14A9M9 = . if (F14A9M9 <= -1 )
replace F14A10 = . if (F14A10 <= -1.00 )
replace F14A10M1 = . if (F14A10M1 <= -1 )
replace F14A10M2 = . if (F14A10M2 <= -1 )
replace F14A10M3 = . if (F14A10M3 <= -1 )
replace F14A10M7 = . if (F14A10M7 <= -1 )
replace F14A10M8 = . if (F14A10M8 <= -1 )
replace F14A10M9 = . if (F14A10M9 <= -1 )
replace F14A11 = . if (F14A11 <= -1.00 )
replace F14A11M1 = . if (F14A11M1 <= -1 )
replace F14A11M2 = . if (F14A11M2 <= -1 )
replace F14A11M3 = . if (F14A11M3 <= -1 )
replace F14A11M7 = . if (F14A11M7 <= -1 )
replace F14A11M8 = . if (F14A11M8 <= -1 )
replace F14A11M9 = . if (F14A11M9 <= -1 )
replace F14A12 = . if (F14A12 <= -1.00 )
replace F14A12M1 = . if (F14A12M1 <= -1 )
replace F14A12M2 = . if (F14A12M2 <= -1 )
replace F14A12M3 = . if (F14A12M3 <= -1 )
replace F14A12M5 = . if (F14A12M5 <= -1 )
replace F14A12M7 = . if (F14A12M7 <= -1 )
replace F14A12M8 = . if (F14A12M8 <= -1 )
replace F14A12M9 = . if (F14A12M9 <= -1 )
replace F15A1 = . if (F15A1 == 7)
replace F15A1 = . if (F15A1 <= -1 )
replace F15A2 = . if (F15A2 == 7)
replace F15A2 = . if (F15A2 <= -1 )
replace F15A3 = . if (F15A3 == 7)
replace F15A3 = . if (F15A3 <= -1 )
replace F15A4 = . if (F15A4 == 7)
replace F15A4 = . if (F15A4 <= -1 )
replace F15A6 = . if (F15A6 == 7)
replace F15A6 = . if (F15A6 <= -1 )
replace F15A7 = . if (F15A7 == 7)
replace F15A7 = . if (F15A7 <= -1 )
replace F15A8 = . if (F15A8 == 7)
replace F15A8 = . if (F15A8 <= -1 )
replace F15A9 = . if (F15A9 == 7)
replace F15A9 = . if (F15A9 <= -1 )
replace F15A10 = . if (F15A10 == 7)
replace F15A10 = . if (F15A10 <= -1 )
replace F15A11 = . if (F15A11 == 7)
replace F15A11 = . if (F15A11 <= -1 )
replace F15A12 = . if (F15A12 == 7)
replace F15A12 = . if (F15A12 <= -1 )
replace F15A13 = . if (F15A13 == 7)
replace F15A13 = . if (F15A13 <= -1 )
replace F15A14 = . if (F15A14 == 7)
replace F15A14 = . if (F15A14 <= -1 )
replace F15A15 = . if (F15A15 == 7)
replace F15A15 = . if (F15A15 <= -1 )
replace F15A16 = . if (F15A16 == 7)
replace F15A16 = . if (F15A16 <= -1 )
replace F15A17 = . if (F15A17 == 7)
replace F15A17 = . if (F15A17 <= -1 )
replace F15A18 = . if (F15A18 == 7)
replace F15A18 = . if (F15A18 <= -1 )
replace F15A19 = . if (F15A19 == 7)
replace F15A19 = . if (F15A19 <= -1 )
replace F15A20 = . if (F15A20 <= -1 )
replace F15A21 = . if (F15A21 <= -1 )
replace F15A22 = . if (F15A22 == 7)
replace F15A22 = . if (F15A22 <= -1 )
replace F15A23 = . if (F15A23 == 7)
replace F15A23 = . if (F15A23 <= -1 )
replace F15A24 = . if (F15A24 == 7)
replace F15A24 = . if (F15A24 <= -1 )
replace F16M1 = . if (F16M1 <= -1 )
replace F16M2 = . if (F16M2 <= -1 )
replace F16M3 = . if (F16M3 <= -1 )
replace F16M4 = . if (F16M4 <= -1 )
replace F16M5 = . if (F16M5 <= -1 )
replace F16M6 = . if (F16M6 <= -1 )
replace F16M7 = . if (F16M7 <= -1 )
replace F16M8 = . if (F16M8 <= -1 )
replace F16M9 = . if (F16M9 <= -1 )
replace F16M11 = . if (F16M11 <= -1 )
replace F16M12 = . if (F16M12 <= -1 )
replace F17 = . if (F17 <= -1 )
replace F17A1 = . if (F17A1 <= -1.00 )
replace F17A1A4 = . if (F17A1A4 <= -1 )
replace F17A1A5 = . if (F17A1A5 <= -1 )
replace F17A2 = . if (F17A2 <= -1.00 )
replace F17A2A4 = . if (F17A2A4 <= -1 )
replace F17A2A5 = . if (F17A2A5 <= -1 )
replace F17A3 = . if (F17A3 <= -1.00 )
replace F17A3A4 = . if (F17A3A4 <= -1 )
replace F17A3A5 = . if (F17A3A5 <= -1 )
replace F17A4 = . if (F17A4 <= -1.00 )
replace F17A4A4 = . if (F17A4A4 <= -1 )
replace F17A4A5 = . if (F17A4A5 <= -1 )
replace F17A5 = . if (F17A5 <= -1.00 )
replace F17A5A4 = . if (F17A5A4 <= -1 )
replace F17A5A5 = . if (F17A5A5 <= -1 )
replace F17A6 = . if (F17A6 <= -1.00 )
replace F17A6A4 = . if (F17A6A4 <= -1 )
replace F17A6A5 = . if (F17A6A5 <= -1 )
replace F17A7 = . if (F17A7 <= -1.00 )
replace F17A7A4 = . if (F17A7A4 <= -1 )
replace F17A7A5 = . if (F17A7A5 <= -1 )
replace F17A8 = . if (F17A8 <= -1.00 )
replace F17A8A4 = . if (F17A8A4 <= -1 )
replace F17A8A5 = . if (F17A8A5 <= -1 )
replace F17A9 = . if (F17A9 <= -1.00 )
replace F17A9A4 = . if (F17A9A4 <= -1 )
replace F17A9A5 = . if (F17A9A5 <= -1 )
replace F17A10 = . if (F17A10 <= -1.00 )
replace F17A10A4 = . if (F17A10A4 <= -1 )
replace F17A10A5 = . if (F17A10A5 <= -1 )
replace F17A11 = . if (F17A11 <= -1.00 )
replace F17A11A4 = . if (F17A11A4 <= -1 )
replace F17A11A5 = . if (F17A11A5 <= -1 )
replace F17A12 = . if (F17A12 <= -1.00 )
replace F17A12A4 = . if (F17A12A4 <= -1 )
replace F17A12A5 = . if (F17A12A5 <= -1 )
replace F17A13 = . if (F17A13 <= -1.00 )
replace F17A13A4 = . if (F17A13A4 <= -1 )
replace F17A13A5 = . if (F17A13A5 <= -1 )
replace F17A14 = . if (F17A14 <= -1.00 )
replace F17A14A4 = . if (F17A14A4 <= -1 )
replace F17A14A5 = . if (F17A14A5 <= -1 )
replace F17B = . if (F17B <= -1 )
replace F18 = . if (F18 <= -1 )
replace F19 = . if (F19 <= -1 )
replace F20 = . if (F20 <= -1 )
replace F20A1 = . if (F20A1 <= -1 )
replace F20A2 = . if (F20A2 <= -1 )
replace F20A3 = . if (F20A3 <= -1 )
replace F20B = . if (F20B == 4)
replace F20B = . if (F20B <= -1 )
replace PRAFMODE = . if (PRAFMODE <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

